# Lab - Implement DHCPv4

[Task](https://www.netacad.com/content/srwe/1.0/courses/content/m7/en-US/assets/7.4.2-lab---implement-dhcpv4.pdf)

### Addressing Table 

| Device | Interface | IP Address | Subnet Mask | Default Gateway |
| --- | --- | --- | --- | --- |
| R1 | G0/0/0 | 10.0.0.1 | 255.255.255.252 | N/A |
| R1 | G0/0/1 | N/A | N/A | N/A |
| R1 | G0/0/1.100 | 192.168.1.1 | 255.255.255.192 | N/A |
| R1 | G0/0/1.200 | 192.168.1.65 | 255.255.255.224 | N/A |
| R1 | G0/0/1.1000 | N/A | N/A | N/A |
| R2 | G0/0/0 | 10.0.0.2 | 255.255.255.252 | N/A |
| R2 | G0/0/1 | 192.168.1.97 | 255.255.255.240 | N/A |
| S1 | VLAN 200 | 192.168.1.66 | 255.255.255.224 | 192.168.1.65 |
| S2 | VLAN 1 | 192.168.1.98 | 255.255.255.240 | 192.168.1.97 |
| PC-A | NIC | DHCP | DHCP | DHCP |
| PC-B | NIC | DHCP | DHCP | DHCP |

### VLAN Table

| VLAN | Name | Interfaces Assigned |
| --- | --- | --- |
| 1 | N/A | S2: (F0/18) |
| 100 | Clients | S1: F0/6 |
| 200 | Management | S1: VLAN 200 |
| 999 | Parking_Lot | S1: F0/1-4, F0/7-24, G0/1-2 |
| 1000 | Native | N/A |

## Objectives
- Part 1: Build the Network and Configure Basic Device Settings
- Part 2: Configure and verify two DHCPv4 Servers on R
- Part 3: Configure and verify a DHCP Relay on R

## Part 1: Build the Network and Configure Basic Device Settings
### Step 1: Establish an addressing scheme
Subnet the network 192.168.1.0/24 to meet the following requirements:

- One subnet, “Subnet A”, supporting 58 hosts (the client VLAN at R1). Record the first IP address in the Addressing Table for R1 G0/0/1.100.

- One subnet, “Subnet B”, supporting 28 hosts (the management VLAN at R1). Record the first IP address in the Addressing Table for R1 G0/0/1.200. Record the second IP address in the Address Table for S1 VLAN 200 and enter the associated default gateway.

- One subnet, “Subnet C”, supporting 12 hosts (the client network at R2). Record the first IP address in the Addressing Table for R2 G0/0/1. Record the second IP address in the
Address Table for S2 VLAN 1 and enter the associated default gateway.

### Step 2: Cable the network as shown in the topology.

### Step 3: Configure basic settings for each router.
Open configuration window. Assign a device name to the router.

- Assign a device name to the router. ```Router(config)# hostname <hostname>```
- Disable DNS lookup to prevent the router from attempting to translate incorrectly entered commands as
though they were host names. ```Router(config)# no ip domain-lookup```
- Assign class as the privileged EXEC encrypted password.```R1(config): enable secret class```
- Assign cisco as the console password and enable login.
    ```
        R1(config)# line con 0
        R1(config-line)# password cisco
        R1(config-line)# login
    ```
- Assign cisco as the VTY password and enable login.
    ```
        R1(config)# line vty 0 1114
        R1(config-line)# password cisco
        R1(config-line)# login
    ```
- Encrypt the plaintext passwords. ```R1(config)# service password-encryption```
- Create a banner that warns anyone accessing the device that unauthorized access is prohibited. ```R1(config)# banner motd # Authorized Access only #```
- Save the running configuration to the startup configuration file. ```R1# write memory```
- Set the clock on the router to today’s time and date. ```R1# clock set HH:MM:SS MON DD YYYY```

### Step 4: Configure Inter-VLAN Routing on R1
- Activate interface G0/0/1 on the router.
- Configure sub-interfaces for each VLAN as required by the IP addressing table. All sub-interfaces use 802.1Q encapsulation and are assigned the first usable address from the IP address pool you have calculated. Ensure the sub-interface for the native VLAN does not have an IP address assigned. Include a description for each sub-interface.
-  Verify the sub-interfaces are operational.

### Step 5: Configure G0/0/1 on R2, then G0/0/0 and static routing for both routers

a. Configure G0/0/1 on R2 with the first IP address of Subnet C you calculated earlier.
b. Configure interface G0/0/0 for each router based on the IP Addressing table above.
c. Configure a default route on each router pointed to the IP address of G0/0/0 on the other router.
d. Verify static routing is working by pinging R2’s G0/0/1 address from R1.
e. Save the running configuration to the startup configuration file.
Close configuration window

### Step 6: Configure basic settings for each switch.
- Assign a device name to the switch.
- Disable DNS lookup to prevent the router from attempting to translate incorrectly entered commands as though they were host names.
- Assign class as the privileged EXEC encrypted password.
- Assign cisco as the console password and enable login.
- Assign cisco as the VTY password and enable login.
- Encrypt the plaintext passwords.
- Create a banner that warns anyone accessing the device that unauthorized access is prohibited.
- Save the running configuration to the startup configuration file.
- Set the clock on the switch to today’s time and date. Note: Use the question mark (?) to help with the correct sequence of parameters needed to execute this command.
- Copy the running configuration to the startup configuration.


### Step 7: Create VLANs on S1.
- Create and name the required VLANs on switch 1 from the table above.
- Configure and activate the management interface on S1 (VLAN 200) using the second IP address from the subnet calculated earlier. Additionally, set the  default gateway on S1.
- Configure and activate the management interface on S2 (VLAN 1) using the second IP address from the subnet calculated earlier. Additionally, set the default gateway on S
- Assign all unused ports on S1 to the Parking_Lot VLAN, configure them for static access mode, and administratively deactivate them. On S2, administratively deactivate all the unused ports.

#### Note: The interface range command is helpful to accomplish this task with as few commands as necessary.

### Step 8: Assign VLANs to the correct switch interfaces.

- Assign used ports to the appropriate VLAN (specified in the VLAN table above) and configure them for
static access mode.
- Verify that the VLANs are assigned to the correct interfaces.
Question:

Why is interface F0/5 listed under VLAN 1?
#### F0/5 will be a trunk port, but trunking will be configured in the future.

### Step 9: Manually configure S1’s interface F0/5 as an 802.1Q trunk.
- Change the switchport mode on the interface to force trunking.
- As a part of the trunk configuration, set the native VLAN to 1000.
- As another part of trunk configuration, specify that VLANs 100, 200, and 1000 are allowed to cross the trunk.
- Save the running configuration to the startup configuration file.
- Verify trunking status.

Question:
At this point, what IP address would the PC’s have if they were connected to the network using DHCP? ```Der PC bekommt eine APIPA Addresse: 169.254.0.0/16```

## Part 2: Configure and verify two DHCPv4 Servers on R
In Part 2, you will configure and verify a DHCPv4 Server on R1. The DHCPv4 server will service two subnets,
Subnet A and Subnet C.

### Step 1: Configure R1 with DHCPv4 pools for the two supported subnets. Only the DHCP Pool for
### subnet A is given below

- Exclude the first five useable addresses from e ach address pool.
- Create the DHCP pool (Use a unique name for each pool).
- Specify the network that this DHCP server is supporting.
- Configure the domain name as ccna-lab.com
- Configure the appropriate default gateway for each DHCP pool.
- Configure the lease time for 2 days 12 hours and 30 minutes.
- Next, configure the second DHCPv4 Pool using the pool name R2_Client_LAN and the calculated network, default-router and use the same domain name and lease time from the previous DHCP pool.

### Step 3: Verify the DHCPv4 Server configuration
- Issue the command show ip dhcp pool to examine the pool details.
- Issue the command show ip dhcp bindings to examine established DHCP address assignments.
- Issue the command show ip dhcp server statistics to examine DHCP messages.

#### Note: Der DHCP Pool zeigt alle IP Addressen an. Auch die, die vorher exkulidert worden sind.

### Step 4: Attempt to acquire an IP address from DHCP on PC-A
- Open a command prompt on PC-A and issue the command ipconfig /renew.
- Once the renewal process is complete, issue the command ipconfig to view the new IP information.
- Test connectivity by pinging R1’s G0/0/1 interface IP address.

## Part 3: Configure and verify a DHCP Relay on R
In Part 3, you will configure R2 to relay DHCP requests from the local area network on interface G0/0/1 to the
DHCP server (R1).

### Step 1: Configure R2 as a DHCP relay agent for the LAN on G0/0/
Open configuration window

- Configure the ip helper-address command on G0/0/1 specifying R1’s G0/0/0 IP address.
- Save your configuration.

### Step 2: Attempt to acquire an IP address from DHCP on PC-B
- Open a command prompt on PC-B and issue the command ipconfig /renew.
- Once the renewal process is complete, issue the command ipconfig to view the new IP information.
- Test connectivity by pinging R1’s G0/0/1 interface IP address.
- Issue the show ip dhcp binding on R1 to verify DHCP bindings.
- Issue the show ip dhcp server statistics on R1 and R2 to verify DHCP messages.


